package com.ibm.etools.gef.examples.shapes;

import org.eclipse.core.resources.IMarker;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorSite;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.views.contentoutline.IContentOutlinePage;

import com.ibm.etools.draw2d.FigureCanvas;
import com.ibm.etools.draw2d.PositionConstants;
import com.ibm.etools.gef.DefaultEditDomain;
import com.ibm.etools.gef.examples.shapes.edit.ShapeEditPartFactory;
import com.ibm.etools.gef.examples.shapes.model.ShapeDiagram;
import com.ibm.etools.gef.palette.PaletteRoot;
import com.ibm.etools.gef.ui.actions.ActionRegistry;
import com.ibm.etools.gef.ui.actions.AlignmentAction;
import com.ibm.etools.gef.ui.parts.*;
import com.ibm.etools.gef.ui.parts.ContextMenuProvider;
import com.ibm.etools.gef.ui.parts.FreeformGraphicalRootEditPart;
import com.ibm.etools.gef.ui.parts.GraphicalEditorWithPalette;
import com.ibm.etools.gef.ui.parts.ScrollingGraphicalViewer;
import com.ibm.etools.gef.ui.stackview.CommandStackInspectorPage;

public class ShapeEditor extends GraphicalEditorWithPalette {

private ContextMenuProvider contextMenuProvider;
private ShapeDiagram shapeDiagram;

public ShapeEditor() {
	setEditDomain(new DefaultEditDomain(this));
}

protected void configureGraphicalViewer() {
	super.configureGraphicalViewer();
	ScrollingGraphicalViewer viewer = (ScrollingGraphicalViewer)getGraphicalViewer();
	viewer.setRootEditPart(new FreeformGraphicalRootEditPart());
	viewer.setEditPartFactory(new ShapeEditPartFactory());
	((FigureCanvas)viewer.getControl()).setScrollBarVisibility(FigureCanvas.ALWAYS);
}

/**
 * @see org.eclipse.ui.IEditorPart#doSave(IProgressMonitor)
 */
public void doSave(IProgressMonitor progressMonitor) {}

/**
 * @see org.eclipse.ui.IEditorPart#doSaveAs()
 */
public void doSaveAs() {}

public Object getAdapter(Class type) {
	if (type == CommandStackInspectorPage.class)
		return new CommandStackInspectorPage(getCommandStack());
	return super.getAdapter(type);
}

/**
 * @see com.ibm.etools.gef.ui.parts.GraphicalEditorWithPalette#getPaletteRoot()
 */
protected PaletteRoot getPaletteRoot() {
	return ShapePlugin.createPalette();
}

protected ShapeDiagram getShapeDiagram() {
	return shapeDiagram;
}

/**
 * @see org.eclipse.ui.IEditorPart#gotoMarker(IMarker)
 */
public void gotoMarker(IMarker marker) {}

/**
 * @see org.eclipse.ui.IEditorPart#init(org.eclipse.ui.IEditorSite, org.eclipse.ui.IEditorInput)
 */
public void init(IEditorSite site, IEditorInput input) throws PartInitException {
	setSite(site);
	setInput(input);
}

protected void initializeActionRegistry() {
	super.initializeActionRegistry();
	ActionRegistry registry = getActionRegistry();
	registry.registerAction(new AlignmentAction(this, PositionConstants.LEFT));
	registry.registerAction(new AlignmentAction(this, PositionConstants.RIGHT));
	registry.registerAction(new AlignmentAction(this, PositionConstants.TOP));
	registry.registerAction(new AlignmentAction(this, PositionConstants.BOTTOM));
	registry.registerAction(new AlignmentAction(this, PositionConstants.CENTER));
	registry.registerAction(new AlignmentAction(this, PositionConstants.MIDDLE));
}

/**
 * @see com.ibm.etools.gef.ui.parts.GraphicalEditor#initializeGraphicalViewer()
 */
protected void initializeGraphicalViewer() {
	getGraphicalViewer().setContents(getShapeDiagram());
}

/**
 * @see org.eclipse.ui.IEditorPart#isDirty()
 */
public boolean isDirty() {
	return false;
}

/**
 * @see org.eclipse.ui.IEditorPart#isSaveAsAllowed()
 */
public boolean isSaveAsAllowed() {
	return false;
}

public void setInput(IEditorInput input) {
	super.setInput(input);
	setShapeDiagram(new ShapeDiagram());
}

protected void setShapeDiagram(ShapeDiagram diagram) {
	shapeDiagram = diagram;
}

}
